@@ -18,7 +18,7 @@ our @EXPORT_OK = qw(
                     remove_trace
                 );
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 $SIG{INT} = sub { 'this ensures END runs if ^C is pressed'; };
 
@@ -67,7 +67,7 @@ sub trace_dump {
     my $data = _store();
 
     if ($want && $want eq 'stack'){
-        if ($out_type eq 'html') {
+        if ($out_type && $out_type eq 'html') {
             html(
                 file => $file,
                 want => $want,
@@ -83,7 +83,7 @@ sub trace_dump {
         }
     }
     if ($want && $want eq 'flow'){
-        if ($out_type eq 'html') {
+        if ($out_type && $out_type eq 'html') {
             html(
                 file => $file,
                 want => $want,
@@ -309,7 +309,7 @@ C<extensions =E<gt> ['pl', 'pm']> - Optional: By default, we change all C<.pm>
 and C<.pl> files. Specify only the extensions you want by adding them into this
 array reference, less the dot.
 
-<inject =E<gt> ['your code here;', 'more code;']> - The lines of code supplied
+C<inject =E<gt> ['your code here;', 'more code;']> - The lines of code supplied
 here will override the default. Note that C<remove_trace()> will not remove
 these lines, and for uninstall, you'll have to manually delete them.
 
@@ -328,15 +328,15 @@ Where 'filename' can be the name of a file, a directory or a 'Module::Name'.
 
 One-liner to install into a live module:
 
-    sudo perl -MDevel::Trace::Subs=install_trace -e 'install_trace(file => "Data::Dump");
+    sudo perl -MDevel::Trace::Subs=install_trace -e 'install_trace(file => "Data::Dump");'
 
 One-liner to test that it worked:
 
-    perl -MDevel::Trace::Subs=trace_dump -e '$ENV{DTS_TRACE}=1; dd {a=>1}; trace_dump();'
+    perl -MData::Dump -MDevel::Trace::Subs=trace_dump -e '$ENV{DTS_TRACE}=1; dd {a=>1}; trace_dump();'
 
 One-liner to uninstall:
 
-    sudo perl -MDevel::Trace::Subs=remove_trace -e 'remove_trace(file => "Data::Dump");
+    sudo perl -MDevel::Trace::Subs=remove_trace -e 'remove_trace(file => "Data::Dump");'
 
 Install into all C<*.pm> files in a directory structure:
 
@@ -350,7 +350,7 @@ Install into all C<*.pm> files in a directory structure:
                 extensions => ['pm'],
              );
 
-See the files in the distributions C<examples> directory for other examples.
+See the files in the distributions C<examples> directory for other examples, and the announcement at PerlMonks L<http://perlmonks.org/?node_id=1141854>.
 
 =head1 AUTHOR
 
@@ -364,6 +364,9 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Devel-Trace-Subs>.  I will
 be notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
 
+=head1 REPOSITORY
+
+L<https://github.com/stevieb9/devel-trace-subs>
 
 =head1 SUPPORT
 
@@ -380,14 +383,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Devel-Trace-Subs>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Devel-Trace-Subs>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Devel-Trace-Subs>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/Devel-Trace-Subs/>
