@@ -9,7 +9,7 @@ use Template;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(text);
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my ($stack_tpl, $flow_tpl, $all_tpl);
 
@@ -94,7 +94,7 @@ $stack_tpl = <<EOF;
 
 Stack trace:
 
-[% FOREACH entry IN stack %]
+[%- FOREACH entry IN stack %]
     in:      [% entry.in %]
     sub:     [% entry.sub %]
     file:    [% entry.filename %]
@@ -110,10 +110,9 @@ Code flow:
 [% FOREACH entry IN flow -%]
     [% entry.name %]: [% entry.value %]
 [% END %]
-
 Stack trace:
 
-[% FOREACH entry IN stack %]
+[%- FOREACH entry IN stack %]
     in:      [% entry.in %]
     sub:     [% entry.sub %]
     file:    [% entry.filename %]
